@@ -565,7 +565,7 @@ SpaPlot <- function(seuInt, batch=NULL, item=NULL, point_size=2,text_size=16,
     if(item %in% colnames(meta_data)){
       sort_id <- sort(as.numeric(as.character((unique(meta_data[, item])))))
       p1 <- plot_scatter(embed_use, meta_data, label_name=item, 
-                         point_size=point_size,palette_use =cols[sort_id])
+                         point_size=point_size, cols =cols[sort_id])
     }else if(item=="RGB_UMAP"){
       p1 <- plot_RGB(embed_use, seu@reductions$UMAP3@cell.embeddings, pointsize = point_size)
     }else if(item=="RGB_TSNE"){
@@ -619,7 +619,7 @@ dimPlot <- function(seuInt, item=NULL, reduction=NULL, point_size=1,text_size=16
   
   embed_use <- seuInt[[reduction]]@cell.embeddings[,c(1,2)]
   p1 <- plot_scatter(embed_use, meta_data, label_name=item, 
-                     point_size=point_size,palette_use =cols)
+                     point_size=point_size,cols =cols)
  
   p1 <- p1 + mytheme_graybox(base_size = text_size, base_family = font_family, bg_fill  = fill_col,
                           border_color = border_col)
